django-central-message
======================

Wrapper for extends-messages to send to multiple users (all for now) from the admin page.

History
-------

0.1.3:

    * Removing pip >= 1.6 requirement from setup.py.

0.1.2:

    * Add support for Django 1.7 migrations.

0.1.1:

    * Adding pip 1.6 support.
